import React from 'react';
import DataListRefresh from './DataListRefresh';
import DataListFilter from './DataListFilter';
import DataListAction from './DataListAction';
import DataListActionMenu from './DataListActionMenu';

/**
 * DataList.Title component.
 * @memberof DataList
 * @name DataList.Head
 * @description Define the DataList head.
 * @since 0.1.2
 * @author liujiali
 * @property {ReactNode} [children] - Children of DataList.Title.
 * @example
 * <DataList>
 *     <DataList.Head>
 *         ......
 *     </DataList.Head>
 *     ......
 * </DataList>
 */
class DataListHead {
    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    constructor(props) {
        const defaultAttrs = [];
        const attrs = this.getChildrenProps(props);
        this.attrs = Object.assign(defaultAttrs, attrs);
    }
    /**
     * Get DataList.Head props.
     * @param {object} props - DataList.Head props.
     * @return {object} DataList head props.
     */
    getChildrenProps(props) {
        const {children} = props;
        const componentOrder = [];
        React.Children.map(children, (child) => {
            const ChildComponent = child.type;
            const childIns = new ChildComponent(child.props);
            if (childIns instanceof DataListRefresh) {
                componentOrder.push({type: 'refresh', attrs: childIns.attrs});
            } else if (childIns instanceof DataListFilter) {
                componentOrder.push({type: 'filter', attrs: childIns.attrs});
            } else if (childIns instanceof DataListAction) {
                componentOrder.push({type: 'action', attrs: childIns.attrs});
            } else if (childIns instanceof DataListActionMenu) {
                componentOrder.push({type: 'menu', attrs: childIns.attrs});
            } else {
                componentOrder.push({type: 'action', attrs: childIns});
            };
        });
        return componentOrder;
    }
}

export default DataListHead;
