import React from 'react';
import DetailColumn from './DetailColumn';

/**
 * Detail.ColumnGroup component.
 * @memberof Detail
 * @name Detail.ColumnGroup
 * @description Define the Detail column group.
 * @since 0.2.4
 * @author liujiali
 * @property {number} [labelWidth=120] - Column label width.
 * @example
 * <Detail>
 *     <Detail.ColumnGroup>
 *         <Detail.Column label='Name' dataKey='name' render: val => val />
 *         ......
 *     </Detail.ColumnGroup>
 *     ......
 * </Detail>
 */
class DetailColumnGroup {
    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    constructor(props) {
        const defaultAttrs = {
            labelWidth: 120,
            columns: [],
        };
        const {children} = props;
        const columns = [];
        React.Children.map(children, (child) => {
            const ChildComponent = child.type;
            const childIns = new ChildComponent(child.props);
            if (childIns instanceof DetailColumn) {
                columns.push(childIns.attrs);
            }
        });
        const attrs = Object.assign(defaultAttrs, {columns: columns});
        this.attrs = attrs;
    }
}

export default DetailColumnGroup;
