import React, {Component} from 'react';
import {InputNumber, Form} from 'antd';
import {pick} from 'lodash';
import {getComponentValidate, getComponentOptions} from './_utils';

const labelProps = [
    'colon', 'extra', 'hasFeedback', 'help', 'label',
    'labelCol', 'required', 'validateStatus', 'wrapperCol',
];

const componentProps = [
    'autoFocus', 'disabled', 'formatter', 'max', 'min',
    'parser', 'precision', 'decimalSeparator', 'size', 'step',
];

/**
 * FormNumber component.
 * @memberof Form
 * @name Form.Number
 * @description InputNumber component.
 * @since 0.2.1
 * @author liujiali
 * @private
 * @example
 * <Form ref={(ins) => this.form = ins}>
 *     <Form.Number label='Name' dataKey='name' />
 *     ......
 * </Form>
*/
class FormNumber extends Component {
    /**
     * Render method.
     * @private
     * @return  {*} No return value.
     */
    render() {
        const {form: {getFieldDecorator}, dataKey} = this.props;
        const labelProp = pick(this.props, labelProps);
        const componentProp = pick(this.props, componentProps);
        const rules = getComponentValidate(this.props);
        const formOptions = getComponentOptions(this.props);
        formOptions.rules = rules;
        return (
            <Form.Item {...labelProp}>
                {getFieldDecorator(dataKey, formOptions)(
                    <InputNumber {...componentProp} />
                )}
            </Form.Item>
        );
    }
}

export default FormNumber;
