import React, {Component} from 'react';
import {Select, Form} from 'antd';
import {pick} from 'lodash';
import {getComponentValidate, getComponentOptions} from './_utils';

const labelProps = [
    'colon', 'extra', 'hasFeedback', 'help', 'label',
    'labelCol', 'required', 'validateStatus', 'wrapperCol',
];

const componentProps = [
    'allowClear', 'autoClearSearchValue', 'autoFocus', 'defaultActiveFirstOption',
    'disabled', 'dropdownClassName', 'dropdownMatchSelectWidth', 'dropdownRender',
    'dropdownStyle', 'filterOption', 'firstActiveValue', 'getPopupContainer', 'labelInValue',
    'maxTagCount', 'maxTagPlaceholder', 'mode', 'notFoundContent', 'optionFilterProp',
    'optionLabelProp', 'placeholder', 'showArrow', 'showSearch', 'size', 'suffixIcon',
    'removeIcon', 'clearIcon', 'menuItemSelectedIcon', 'tokenSeparators', 'loading',
    'open', 'defaultOpen',
];

/**
 * FormSelect component.
 * @memberof Form
 * @name Form.Select
 * @description Select component.
 * @since 0.2.1
 * @author liujiali
 * @private
 * @example
 * <Form ref={(ins) => this.form = ins}>
 *     <Form.Select label='Name' dataKey='name' options={[]} />
 *     ......
 * </Form>
*/
class FormSelect extends Component {
    /**
     * Render method.
     * @private
     * @return  {*} No return value.
     */
    render() {
        const {form: {getFieldDecorator}, dataKey, options = []} = this.props;
        const labelProp = pick(this.props, labelProps);
        const componentProp = pick(this.props, componentProps);
        const rules = getComponentValidate(this.props);
        const formOptions = getComponentOptions(this.props);
        formOptions.rules = rules;
        return (
            <Form.Item {...labelProp}>
                {getFieldDecorator(dataKey, formOptions)(
                    <Select {...componentProp}>
                        {options.map((opt) => (
                            <Select.Option key={opt.value}>{opt.label}</Select.Option>
                        ))}
                    </Select>
                )}
            </Form.Item>
        );
    }
}

export default FormSelect;
