import React, {Component} from 'react';
import {Input, Form} from 'antd';
import {pick} from 'lodash';
import {getComponentValidate, getComponentOptions} from './_utils';

const labelProps = [
    'colon', 'extra', 'hasFeedback', 'help', 'label',
    'labelCol', 'required', 'validateStatus', 'wrapperCol',
];

const componentProps = [
    'addonAfter', 'addonBefore', 'disabled', 'id', 'prefix',
    'size', 'suffix', 'type', 'onPressEnter', 'allowClear',
];

/**
 * FormText component.
 * @memberof Form
 * @name Form.Text
 * @description Input component.
 * @since 0.2.1
 * @author liujiali
 * @private
 * @example
 * <Form ref={(ins) => this.form = ins}>
 *     <Form.Text label='Name' dataKey='name' />
 *     ......
 * </Form>
*/
class FormText extends Component {
    /**
     * Render method.
     * @private
     * @return  {*} No return value.
     */
    render() {
        const {form: {getFieldDecorator}, dataKey} = this.props;
        const labelProp = pick(this.props, labelProps);
        const componentProp = pick(this.props, componentProps);
        const rules = getComponentValidate(this.props);
        const formOptions = getComponentOptions(this.props);
        formOptions.rules = rules;
        return (
            <Form.Item {...labelProp}>
                {getFieldDecorator(dataKey, formOptions)(
                    <Input {...componentProp} />
                )}
            </Form.Item>
        );
    }
}

export default FormText;
