import {pick, isObject} from 'lodash';

const rules = [
    'enum', 'len', 'max', 'min', 'pattern', 'required',
    'transform', 'type', 'validator', 'whitespace',
];

const options = [
    'getValueFromEvent', 'initialValue', 'normalize', 'preserve',
    'trigger', 'validateFirst', 'validateTrigger', 'valuePropName',
];
/**
 * Return component validate by props.
 * @param {object} props Component props.
 * @return {Array} Component validate rule list.
 */
function getComponentValidate(props) {
    const ruleList = pick(props, rules);
    const {message} = props;
    const rule = [];
    // eslint-disable-next-line guard-for-in
    for (const validate in ruleList) {
        rule.push({
            [validate]: ruleList[validate],
            message: isObject(message) ? message[validate] : message,
        });
    }
    return rule;
}
/**
 * Return `getFieldDecorator` function options.
 * @param {object} props Component props.
 * @return {object} `getFieldDecorator` options.
 */
function getComponentOptions(props) {
    const option = pick(props, options);
    return option;
}

export {getComponentValidate};
export {getComponentOptions};
