import React, {Component} from 'react';
import {Form as AntdForm} from 'antd';
import {pick} from 'lodash';
import {exec, isBlank} from 'rc-js-utils';
import FormText from './FormText';
import FormArea from './FormTextArea';
import FormNumber from './FormNumber';
import FormSelect from './FormSelect';

const formProps = [
    'hideRequiredMark', 'labelAlign', 'labelCol', 'layout', 'onSubmit', 'wrapperCol', 'colon',
];

const defaultFormLayout = {
    labelCol: {span: 2},
    wrapperCol: {span: 10, offset: 0.5},
};

/**
 * Form component.
 * @memberof Form
 * @description Form component.
 * @since 0.2.1
 * @author liujiali
 * @private
 * @example
 * <Form ref={(ins) => this.form = ins}>
 *     <Form.Number label='Name' dataKey='name' />
 *     ......
 * </Form>
*/
class Form extends Component {
    static Text = FormText;
    static TextArea = FormArea;
    static Number = FormNumber;
    static Select = FormSelect;
    /**
     * Render method.
     * @private
     * @return  {*} No return value.
     */
    render() {
        const {children, form} = this.props;
        const component = [];
        const formValues = form.getFieldsValue();
        React.Children.map(children, (child) => {
            const {props, type} = child;
            const Component = type;
            const {visible, dataKey} = props;
            const formValue = formValues[dataKey];
            if (!isBlank(visible) && !exec(visible, formValue, formValues)) {
                return;
            }
            component.push(
                <Component {...props} form={form} />
            );
        });
        const formProp = pick(this.props, formProps);
        return (
            <AntdForm {...defaultFormLayout} labelAlign='left' {...formProp}>
                {component}
            </AntdForm>
        );
    }
}

export default AntdForm.create()(Form);
