import {Component} from 'react';
import validateField from './validate';
import {exec} from 'rc-js-utils';
import {Subject} from 'rxjs';

/**
 * Input basic component.
 * @name BasicComponent
 * @since 0.3.3
 * @author liujiali
 */
class BasicComponent extends Component {
    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    constructor(props) {
        super(props);
        const {initValue} = props;
        this.state = {
            value: initValue,
            error: false,
        };
        this.validate = validateField(props);
    }
    /**
     * componentDidMount hook function.
     * @private
     */
    componentDidMount() {
        const {trigger, onChange} = this.props;
        if (trigger instanceof Subject) {
            trigger.subscribe(() => {
                const {value} = this.state;
                let error = false;
                if (!this.validate(value)) {
                    error = true;
                }
                this.setState({
                    value: value,
                    error,
                }, () => {
                    exec(onChange, this.state.value, this.state.error);
                });
            });
        }
    }
    /**
     * Handle input onChange event.
     * @param  {function} handler=val=>val
     * @return {function} onChange event handler.
     */
    onChange(handler = (val) => val) {
        return (val) => {
            const {onChange} = this.props;
            const value = exec(handler, val);
            let error = false;
            if (!this.validate(value)) {
                error = true;
            }
            this.setState({
                value: value,
                error,
            }, () => {
                exec(onChange, this.state.value, this.state.error);
            });
        };
    }
}

export default BasicComponent;
