import React, {Fragment} from 'react';
import {Select as AntdSelect} from 'antd';
import BasicComponent from './BasicComponent';
import {getDefaultSettings} from '../index';
import {isArray, find} from 'lodash';

const LOCALE = {
    zh: {
        notFoundContent: '暂无数据',
    },
    en: {
        notFoundContent: 'No Data',
    },
};
/**
 * Select component.
 * @name Select
 * @since 0.3.5
 * @author liujiali
 */
class Select extends BasicComponent {
    /**
     * componentDidUpdate hook function.
     * @param {any} prevProps - Previous props.
     * @private
     */
    componentDidUpdate(prevProps) {
        if (prevProps.options !== this.props.options) {
            const {options} = this.props;
            const {value} = this.state;
            let currentValue = undefined;
            if (isArray(value)) {
                currentValue = [];
                value.forEach((val) => {
                    if (options.map((i) => i.value).indexOf(val) !== -1) {
                        currentValue.push(val);
                    }
                });
                currentValue = currentValue.length ? currentValue : undefined;
            } else {
                const currentOpt = find(options, (i) => i.value === value);
                currentValue = currentOpt ? currentOpt.value : undefined;
            }
            this.setState({
                value: currentValue,
            });
        }
    }
    /**
     * Render method.
     * @return  {*} No return value.
     */
    render() {
        const {options = []} = this.props;
        const {value, error} = this.state;
        const settings = getDefaultSettings();
        const {locale} = settings;
        return (
            <Fragment>
                <div className={error ? 'has-error' : ''}>
                    <AntdSelect style={{width: '100%'}}
                        {...this.props} value={value} onChange={this.onChange()}
                        notFoundContent={LOCALE[locale].notFoundContent}>
                        {options.map((opt, index) => (
                            <AntdSelect.Option value={opt.value} key={index}>
                                {opt.label}
                            </AntdSelect.Option>
                        ))}
                    </AntdSelect>
                </div>
            </Fragment>
        );
    }
}

export default Select;
