'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _lodash = require('lodash');

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * DataList.Action component.
 * @memberof DataList
 * @name DataList.Action
 * @description Define the DataList action.
 * @since 0.1.0
 * @author liujiali
 * @property {string} [label='action'] - Action label.
 * @property {onClick} onClick - Action click function.
 * @property {boolean} [visible=true] - Whether action is visible.
 * @property {string} [type] - Action type.[`primary`, `default`].
 * @property {boolean|object|function} [disabled] - Whether action is disabled.
 * @property {boolean} disabled.isDisabled - Whether action is disabled.
 * @property {string} [disabled.message] - Action disabled message.
 * @example
 * <DataList>
 *     <DataList.Action label='Add' onClick={this.handleAdd} visible={true} type='primary'
 *                      disabled={true}  />
 *     <DataList.Action label='Modify' onClick={this.handleModify} visible={true} type='primary'
 *                      disabled={{isDisabled: true, message: 'Can not modify!'}} />
 *     <DataList.Action label='Delete' onClick={this.handleDelete} visible={true} type='primary'
 *                      disabled={(record) => {return {isDisabled: !record, message: 'No record!'}}} />
 *     ......
 * </DataList>
 */
var DataListAction =
/**
 * Create and initialize component.
 * @param {*} props - Component props.
 */
function DataListAction(props) {
    _classCallCheck(this, DataListAction);

    var defaultAttrs = {
        label: 'action',
        onClick: function onClick() {
            return null;
        },
        type: 'default',
        visible: true,
        disabled: false
    };
    var attrs = Object.assign(defaultAttrs, props);
    if ((0, _lodash.isBoolean)(attrs.disabled)) {
        attrs.disabled = { isDisabled: attrs.disabled };
    };
    this.attrs = attrs;
};

exports.default = DataListAction;

/**
 * Action onClick function description.
 * @callback onClick
 * @param {object} record - The whole record value.
 * @param {number} index - The record index.
 */