'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _DataListAction = require('./DataListAction');

var _DataListAction2 = _interopRequireDefault(_DataListAction);

var _index = require('../index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var LOCALE = {
    zh: {
        actionMenuLabel: '操作'
    },
    en: {
        columnActionTitle: 'Action'
    }
};

/**
 * DataList.ActionMenu component.
 * @memberof DataList
 * @name DataList.ActionMenu
 * @description Define the DataList action menu.
 * @since 0.1.5
 * @author liujiali
 * @property {string} [label=Action] - Action menu label.
 * @property {string} [type=default] - Action menu button type.<br/>[`primary`, `default`]
 * @property {DataList.Action} children - Action of DataList.ActionMenu
 * @example
 * <DataList>
 *     <DataList.Head>
 *         <DataList.ActionMenu>
 *             <DataList.Action label='Add' onClick={(keys) => alert(keys)} />
 *             ......
 *         </DataList.ActionMenu>
 *     </DataList.Head>
 *     ......
 * </DataList>
 */

var DataListActionMenu =
/**
 * Create and initialize component.
 * @param {*} props - Component props.
 */
function DataListActionMenu(props) {
    _classCallCheck(this, DataListActionMenu);

    var settings = (0, _index.getDefaultSettings)();
    var locale = settings.locale;
    var label = props.label,
        _props$type = props.type,
        type = _props$type === undefined ? 'default' : _props$type,
        _props$float = props.float,
        float = _props$float === undefined ? 'left' : _props$float;

    var defaultAttrs = {
        label: label || LOCALE[locale].actionMenuLabel,
        actions: [],
        type: type,
        float: float
    };
    var children = props.children;

    var actions = [];
    _react2.default.Children.map(children, function (child) {
        var ChildComponent = child.type;
        var childIns = new ChildComponent(child.props);
        if (childIns instanceof _DataListAction2.default) {
            actions.push(childIns.attrs);
        }
    });
    this.attrs = Object.assign(defaultAttrs, { actions: actions });
};

exports.default = DataListActionMenu;