'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _badge = require('antd/lib/badge');

var _badge2 = _interopRequireDefault(_badge);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd/lib/badge/style');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _rcJsUtils = require('rc-js-utils');

var _lodash = require('lodash');

var _Input = require('../Input');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * DataList.Column component.
 * @memberof DataList
 * @name DataList.Column
 * @description Define the DataList column.
 * @since 0.1.0
 * @author liujiali
 * @property {string} [label=null] - Column label.
 * @property {string} dataKey - Column data key.
 * @property {boolean} [sort=false] - Enable column sort.
 * @property {enum} [defaultSort=null] - Default sort order.
 * @property {render} [render=function(value) { return value ? value : '-' }] - Column render method.
 * @property {boolean} [visible=true] - Whether column is visible.
 * @property {string} [type] - Column type.Effective when type=`list`.
 * @property {string|object} [convert=null] - Several predefined render method.[`date`, `status`, `number`, `string`].
 *                                            <br/>If the `render` property is defined, this props will not be used.
 * @property {enum} convert.type - Convert type.[`date`, `status`, `number`, `string`].
 * @property {string} [convert.format=`YYYY-MM-DD HH:mm:ss`] - Effective when type=`date`.<br/>Date format.
 * @property {number} [convert.timezone=local timezone] - Effective when type=`date`.<br/>Date convert target timezone.
 * @property {object} [convert.statusMap] - Effective when type=`status`.<br/>Status map.
 * @property {string} convert.statusMap.key - Status map key.
 * @property {string} convert.statusMap.value - Status map value.<br/>[`success`, `warning`, `error`, `processing`, `default`].
 * @property {function} [convert.render] - Status label render.
 * @property {string} [help] - Column help message.
 * @example
 * <DataList>
 *     <DataList.Column label='Name' dataKey='name' sort={true} defaultSort='descend' />
 *     <DataList.Column label='Display Name' dataKey='displayName' visible={false} />
 *     <DataList.Column label='Created Time' dataKey='createdTime' convert='date' help='This is when application created.' />
 *     ......
 * </DataList>
 */
var DataListColumn = function () {
    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    function DataListColumn(props) {
        _classCallCheck(this, DataListColumn);

        var defaultAttrs = {
            label: '',
            dataKey: null,
            sort: false,
            defaultSort: null,
            render: this.getDefaultRender(props),
            visible: true,
            type: null,
            convert: null,
            help: null
        };
        this.attrs = Object.assign(defaultAttrs, props);
        var _attrs = this.attrs,
            convert = _attrs.convert,
            label = _attrs.label;

        if ((0, _lodash.isObject)(convert) && convert.required) {
            this.attrs.label = _react2.default.createElement(
                'label',
                { className: 'ant-form-item-required' },
                label
            );
        }
    }
    /**
     * Return default render method for column.
     * @since 0.1.1
     * @author liujiali
     * @private
     * @param {*} props - Component props.
     * @return {render} Column render method.
     */


    _createClass(DataListColumn, [{
        key: 'getDefaultRender',
        value: function getDefaultRender(props) {
            var defaultRender = function defaultRender(value) {
                return (0, _rcJsUtils.isBlank)(value) ? '-' : value;
            };
            if (!props.convert) return defaultRender;
            var convert = {};
            (0, _lodash.isString)(props.convert) ? convert.type = props.convert : convert = props.convert;
            return this.getConvertRender(convert);
        }
        /**
         * Return render method by convert type.
         * @since 0.1.1
         * @author liujiali
         * @private
         * @param {object} convert - Column convert property.
         * @return {render} Column render method.
         */

    }, {
        key: 'getConvertRender',
        value: function getConvertRender(convert) {
            var _this = this;

            var type = convert.type;
            var render = void 0;
            switch (type) {
                // `string` type.
                case 'string':
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : (0, _rcJsUtils.formatString)(value);
                    };
                    break;
                // `number` type.
                case 'number':
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : (0, _rcJsUtils.formatNumber)(value);
                    };
                    break;
                // `date` type.
                case 'date':
                    var format = convert.format,
                        timezone = convert.timezone;

                    var opts = {};
                    if (format) opts.format = format;
                    if (!(0, _rcJsUtils.isBlank)(timezone)) opts.timezone = timezone;
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : (0, _rcJsUtils.convertToLocalDate)(value, opts);
                    };
                    break;
                // `string` type.
                case 'status':
                    var statusMap = convert.statusMap;

                    if (!statusMap) {
                        statusMap = {
                            success: 'success',
                            error: 'error',
                            default: 'default',
                            processing: 'processing',
                            warning: 'warning'
                        };
                    }
                    var statusRender = convert.render || function (val) {
                        return (0, _rcJsUtils.formatString)(val);
                    };
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : _react2.default.createElement(_badge2.default, { status: statusMap[value],
                            text: (0, _rcJsUtils.exec)(statusRender, value) });
                    };
                    break;
                case 'input':
                    render = function render(value, record, index, ins) {
                        var onChange = function onChange(val, error) {
                            record[_this.attrs.dataKey] = val;
                            if (!record.fieldsError) {
                                record.fieldsError = {};
                            }
                            record.fieldsError[_this.attrs.dataKey] = error;
                            ins.setState(_extends({}, ins.state));
                        };
                        return _react2.default.createElement(_Input.Input, _extends({ initValue: value, trigger: ins.fieldsTrigger
                        }, convert, { onChange: onChange, key: ins.state.loadCount }));
                    };
                    break;
                case 'select':
                    render = function render(value, record, index, ins) {
                        var onChange = function onChange(value, error) {
                            record[_this.attrs.dataKey] = value;
                            if (!record.fieldsError) {
                                record.fieldsError = {};
                            }
                            record.fieldsError[_this.attrs.dataKey] = error;
                            ins.setState(_extends({}, ins.state));
                        };
                        var options = convert.options;

                        options = (0, _rcJsUtils.exec)(options, value, record, index);
                        var currentOption = undefined;
                        if ((0, _lodash.isArray)(value)) {
                            currentOption = [];
                            value.forEach(function (val) {
                                if (options.map(function (i) {
                                    return i.value;
                                }).indexOf(val) !== -1) {
                                    currentOption.push(val);
                                }
                            });
                            currentOption = currentOption.length ? currentOption : undefined;
                        } else {
                            currentOption = (0, _lodash.find)(options, function (i) {
                                return i.value === value;
                            });
                        }
                        if (value && !currentOption) {
                            record[_this.attrs.dataKey] = undefined;
                        }
                        return _react2.default.createElement(_Input.Select, _extends({ initValue: value, trigger: ins.fieldsTrigger
                        }, convert, { onChange: onChange, options: options, key: ins.state.loadCount }));
                    };
                    break;
                case 'inputNumber':
                    render = function render(value, record, index, ins) {
                        var onChange = function onChange(val, error) {
                            record[_this.attrs.dataKey] = val;
                            if (!record.fieldsError) {
                                record.fieldsError = {};
                            }
                            record.fieldsError[_this.attrs.dataKey] = error;
                            ins.setState(_extends({}, ins.state));
                        };
                        return _react2.default.createElement(_Input.InputNumber, _extends({ initValue: value, trigger: ins.fieldsTrigger
                        }, convert, { onChange: onChange, key: ins.state.loadCount }));
                    };
                    break;
                default:
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : value;
                    };
            };
            return render;
        }
    }]);

    return DataListColumn;
}();

exports.default = DataListColumn;

/**
 * render method description.
 * @callback render
 * @param {*} value - The column value.
 * @param {object} record - The whole record value.
 * @param {number} index - The record index.
 */