"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * DataList.Column component.
 * @memberof DataList
 * @name DataList.Pagination
 * @description Define the DataList pagination.
 * @since 0.1.0
 * @author liujiali
 * @property {number} [pageSize=10] - Number of data items per page.
 * @property {string[]} [pageSizeOptions] - Specify the sizeChanger options.
 * @example
 * <DataList>
 *     ......
 *     <DataList.Pagination pageSizeOptions={['5', '10']} />
 * </DataList>
 */
var DataListColumn =
/**
 * Create and initialize component.
 * @param {*} props - Component props.
 */
function DataListColumn(props) {
    _classCallCheck(this, DataListColumn);

    var defaultAttrs = {
        defaultPageSize: 10,
        showSizeChanger: false
    };
    var attrs = Object.assign(defaultAttrs, props);
    if (attrs.pageSizeOptions) {
        attrs.showSizeChanger = true;
        var defaultPageSizeStr = attrs.defaultPageSize.toString();
        if (attrs.pageSizeOptions.indexOf(defaultPageSizeStr) === -1) {
            attrs.defaultPageSize = parseInt(attrs.pageSizeOptions[0], 10);
        }
    }
    this.attrs = attrs;
};

exports.default = DataListColumn;