'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _tag = require('antd/lib/tag');

var _tag2 = _interopRequireDefault(_tag);

var _dropdown = require('antd/lib/dropdown');

var _dropdown2 = _interopRequireDefault(_dropdown);

var _icon = require('antd/lib/icon');

var _icon2 = _interopRequireDefault(_icon);

var _menu = require('antd/lib/menu');

var _menu2 = _interopRequireDefault(_menu);

var _tooltip = require('antd/lib/tooltip');

var _tooltip2 = _interopRequireDefault(_tooltip);

var _button = require('antd/lib/button');

var _button2 = _interopRequireDefault(_button);

var _row = require('antd/lib/row');

var _row2 = _interopRequireDefault(_row);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd/lib/tag/style');

require('antd/lib/dropdown/style');

require('antd/lib/icon/style');

require('antd/lib/menu/style');

require('antd/lib/tooltip/style');

require('antd/lib/button/style');

require('antd/lib/row/style');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _DataListColumn = require('./DataListColumn');

var _DataListColumn2 = _interopRequireDefault(_DataListColumn);

var _DataListAction = require('./DataListAction');

var _DataListAction2 = _interopRequireDefault(_DataListAction);

var _DataListPagination = require('./DataListPagination');

var _DataListPagination2 = _interopRequireDefault(_DataListPagination);

var _DataListTable = require('./DataListTable');

var _DataListTable2 = _interopRequireDefault(_DataListTable);

var _rcJsUtils = require('rc-js-utils');

var _lodash = require('lodash');

var _DataListTitle = require('./DataListTitle');

var _DataListTitle2 = _interopRequireDefault(_DataListTitle);

var _DataListHead = require('./DataListHead');

var _DataListHead2 = _interopRequireDefault(_DataListHead);

var _DataListRefresh = require('./DataListRefresh');

var _DataListRefresh2 = _interopRequireDefault(_DataListRefresh);

var _DataListFilter = require('./DataListFilter');

var _DataListFilter2 = _interopRequireDefault(_DataListFilter);

var _DataListActionMenu = require('./DataListActionMenu');

var _DataListActionMenu2 = _interopRequireDefault(_DataListActionMenu);

var _rxjs = require('rxjs');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var headMarginMap = {
    left: { marginRight: 8 },
    right: { marginLeft: 8 }
};

/**
 * DataList component.
 * @namespace DataList
 * @description Component lifecycle:
 * <br/> componentDidMount --> loadTrigger --> beforeLoadData --> handleRequestData --> startLoadingData --> handleResponseData --> afterLoadData --> render
 * @property {enum} [type=`table`] - DataList type.<br/>[`table`, `list`, `card`].
 * @property {*} data - The DataList component `data` used for `handleRequestData` function.
 * @property {beforeLoadData} beforeLoadData - Hook function before start loading data.
 * @property {afterLoadData} afterLoadData - Hook function after loading data.
 * @property {enum|object} [rowSelection] - Properties for row selection.[`checkbox`, `radio`].
 *                                          <br/>For more detail, please see https://ant.design/components/table/#rowSelection.
 * @example
 * <DataList type='table' data={{url: '/api/test'}} rowSelection='checkbox'>
 * ......
 * </DataList>
*/

var DataList = function (_Component) {
    _inherits(DataList, _Component);

    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    function DataList(props) {
        _classCallCheck(this, DataList);

        var _this = _possibleConstructorReturn(this, (DataList.__proto__ || Object.getPrototypeOf(DataList)).call(this, props));

        var pagination = _this.getDefineFromProps(props.children, _DataListPagination2.default);
        var columns = _this.getDefineFromProps(props.children, _DataListColumn2.default);
        var sorts = [];
        columns.forEach(function (col) {
            if (col.defaultSort) {
                sorts.push({ key: col.dataKey, value: col.defaultSort });
            }
        });
        pagination = pagination.length ? pagination[0] : false;
        _this.fieldsTrigger = new _rxjs.Subject();
        _this.state = {
            filters: [],
            sorts: sorts,
            pagination: {
                currentPage: 1,
                pageSize: pagination ? pagination.pageSize : 0,
                total: 0
            },
            loading: false,
            data: [],
            // TODO: default value
            selectedKeys: [],
            selectedRows: [],
            loadData: function loadData() {
                return _this.loadData();
            },
            props: props,
            columns: columns,
            loadCount: 0
        };
        return _this;
    }

    _createClass(DataList, [{
        key: 'componentDidMount',

        /**
         * componentDidMount hook function.
         * @private
         */
        value: function componentDidMount() {
            this.loadTriggerCallback = (0, _rcJsUtils.exec)(DataList.loadTrigger, this.startLoadingData());
        }
    }, {
        key: 'componentWillUnmount',

        /**
         * componentWillUnmount hook function.
         * @private
         */
        value: function componentWillUnmount() {
            (0, _rcJsUtils.exec)(this.loadTriggerCallback);
        }
    }, {
        key: 'componentDidUpdate',

        /**
         * componentDidUpdate hook function.
         * @param {any} prevProps - Previous props.
         * @private
         */
        value: function componentDidUpdate(prevProps) {
            if (!(0, _lodash.isEqual)(prevProps.data, this.props.data)) {
                this.loadData(true);
            }
        }
    }, {
        key: 'getDefineFromProps',

        /**
         * Get the definition of column, action and etc. by parameters.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @param  {ReactNode|ReactNode[]} children - Component children nodes.
         * @param  {class} targetClass - Component class.
         * @return {Array} Component definition list.
         */
        value: function getDefineFromProps(children, targetClass) {
            var attrs = [];
            _react2.default.Children.map(children, function (child) {
                var ChildComponent = child.type;
                var childIns = new ChildComponent(child.props);
                if (childIns instanceof targetClass) {
                    attrs.push(childIns.attrs);
                }
            });
            return attrs;
        }
    }, {
        key: 'startLoadingData',

        /**
         * Load data function.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @return {callback} startLoadingData function.
         */
        value: function startLoadingData() {
            var _this2 = this;

            return function (silent) {
                var _props = _this2.props,
                    data = _props.data,
                    beforeLoadData = _props.beforeLoadData,
                    stopSilentLoad = _props.stopSilentLoad;

                if (stopSilentLoad && silent) return;
                var _state = _this2.state,
                    pagination = _state.pagination,
                    filters = _state.filters,
                    sorts = _state.sorts;
                // Set table loading status by `silent`.

                _this2.setState({
                    loading: !silent
                });
                var requestParams = [data, pagination, filters, sorts];
                if ((0, _lodash.isFunction)(beforeLoadData)) {
                    requestParams = beforeLoadData(data, pagination, filters, sorts);
                }
                // Start load data.
                var response = DataList.handleRequestData.apply(DataList, _toConsumableArray(requestParams));
                if (response instanceof Promise) {
                    response.then(function (result) {
                        _this2.handleLoadData(result, silent);
                    });
                } else {
                    _this2.handleLoadData(response, silent);
                }
            };
        }
        /**
         * Completed unset parameter if developers do not return the
         * `pagination`, `filters`, `sorts` parameters in `afterLoadData` and `handleResponseData` function.
         * @since 0.1.0
         * @author liujiali
         * @deprecated
         * @private
         * @param  {*} response - startLoadingData response.
         * @return {object} - DataList expected return value.
         */

    }, {
        key: 'handleUnsetResult',
        value: function handleUnsetResult(response) {
            var data = response.data,
                pagination = response.pagination,
                filters = response.filters,
                sorts = response.sorts;

            if ((0, _rcJsUtils.isBlank)(data)) data = [];
            if ((0, _rcJsUtils.isBlank)(pagination)) pagination = this.state.pagination;
            if ((0, _rcJsUtils.isBlank)(filters)) filters = this.state.filters;
            if ((0, _rcJsUtils.isBlank)(sorts)) sorts = this.state.sorts;
            return {
                data: data,
                pagination: pagination,
                filters: filters,
                sorts: sorts
            };
        }
        /**
         * Hook function after `handleResponseData` function.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @param {*} response - startLoadingData response.
         * @param {boolean} silent - Show loading or not.
         */

    }, {
        key: 'handleLoadData',
        value: function handleLoadData(response, silent) {
            var _this3 = this;

            var _props2 = this.props,
                afterLoadData = _props2.afterLoadData,
                data = _props2.data;
            var _state2 = this.state,
                pagination = _state2.pagination,
                filters = _state2.filters,
                sorts = _state2.sorts,
                loadCount = _state2.loadCount;

            response = DataList.handleResponseData(response, pagination, filters, sorts, data);
            var tData = void 0;
            var tPagination = void 0;
            var tFilters = void 0;
            var tSorts = void 0;
            if ((0, _lodash.isFunction)(afterLoadData)) {
                tData = response.data;
                tPagination = response.pagination;
                tFilters = response.filters;
                tSorts = response.sorts;
                response = afterLoadData(tData, tPagination, tFilters, tSorts, data);
            }
            Promise.all([response]).then(function (results) {
                var result = results[0];
                tData = result.data;
                tPagination = result.pagination;
                tFilters = result.filters;
                tSorts = result.sorts;
                var rowKey = _this3.props.rowKey;
                var _state3 = _this3.state,
                    selectedKeys = _state3.selectedKeys,
                    selectedRows = _state3.selectedRows;

                var currentSelectedKeys = selectedKeys;
                var currentSelectedRows = selectedRows;
                if (rowKey) {
                    var currentRowKeys = tData.map(function (i) {
                        return i[rowKey];
                    });
                    currentSelectedKeys = selectedKeys.filter(function (i) {
                        currentRowKeys.indexOf(i) !== -1;
                    });
                    currentSelectedRows = selectedRows.filter(function (i) {
                        currentRowKeys.indexOf(i[rowKey]) !== -1;
                    });
                }
                _this3.setState({
                    loading: false,
                    filters: tFilters,
                    sorts: tSorts,
                    pagination: tPagination,
                    data: tData,
                    loadCount: silent ? loadCount : loadCount + 1,
                    selectedKeys: currentSelectedKeys,
                    selectedRows: currentSelectedRows
                });
            });
        }
        /**
         * render DataList componet.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @param {boolen} condition - Whether render component.
         * @param {ReactNode} Component - DataList component.
         * @return {ReactNode} DataList component.
         */

    }, {
        key: 'renderComponet',
        value: function renderComponet(condition, Component) {
            if (condition) {
                var children = this.props.children;

                var columns = this.getDefineFromProps(children, _DataListColumn2.default);
                var columnActions = this.getDefineFromProps(children, _DataListAction2.default);
                var pagination = this.getDefineFromProps(children, _DataListPagination2.default);
                pagination = pagination.length ? pagination[0] : false;
                // Handle pagination.
                if (pagination) {
                    var _state$pagination = this.state.pagination,
                        currentPage = _state$pagination.currentPage,
                        pageSize = _state$pagination.pageSize,
                        total = _state$pagination.total;
                    var _pagination = pagination,
                        defaultPageSize = _pagination.defaultPageSize;

                    pagination.current = currentPage;
                    pagination.pageSize = pageSize || defaultPageSize;
                    pagination.total = total;
                }
                return _react2.default.createElement(Component, _extends({}, this.props, {
                    data: this.state.data,
                    columns: columns,
                    actions: columnActions,
                    loading: this.state.loading,
                    pagination: pagination,
                    filters: this.state.filters,
                    sorts: this.state.sorts,
                    instance: this,
                    selectedKeys: this.state.selectedKeys,
                    onChange: this.handleDataListChange(),
                    onSelect: this.handleDataListSelect() }));
            } else {
                return null;
            }
        }
        /**
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param {object} title - DataList.Title props.
         * @return {ReactNode} - DataList.Title ReactNode.
         */

    }, {
        key: 'renderComponentTitle',
        value: function renderComponentTitle(title) {
            var titleStyle = {
                position: 'relative',
                marginBottom: 16,
                fontSize: 20,
                lineHeight: '28px'
            };
            var titleClassName = 'rc-ui-component-datalist-title';
            return _react2.default.createElement(
                _react.Fragment,
                null,
                title.title ? _react2.default.createElement(
                    'div',
                    { className: titleClassName,
                        style: titleStyle },
                    title.title
                ) : null,
                title.children ? title.children : null
            );
        }
        /**
         * Render DataList head.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param  {object} head - DataList.Head props.
         * @return {ReactNode} DataList head ReactNode.
         */

    }, {
        key: 'renderComponentHead',
        value: function renderComponentHead(head) {
            var _this4 = this;

            if ((0, _lodash.isEmpty)(head)) return null;
            // Define head in-line style.
            var headStyle = {
                height: 'auto',
                marginBottom: 6
            };
            var noHead = !head.length;
            var filter = (0, _lodash.find)(head, function (h) {
                return h.type === 'filter';
            });
            return noHead ? null : _react2.default.createElement(
                _react.Fragment,
                null,
                _react2.default.createElement(
                    _row2.default,
                    { style: headStyle },
                    head.map(function (component) {
                        switch (component.type) {
                            case 'refresh':
                                return _this4.renderComponentHeadRefresh(component.attrs);
                            case 'filter':
                                return _this4.renderComponentHeadFilters(component.attrs);
                            case 'action':
                                return _this4.renderComponentHeadActions(component.attrs);
                            case 'menu':
                                return _this4.renderComponentHeadMenus(component.attrs);
                            default:
                                return null;
                        }
                    })
                ),
                _react2.default.createElement(
                    _row2.default,
                    { style: { marginBottom: 6 } },
                    filter && !filter.attrs.multiple ? this.renderFilterTags() : null
                )
            );
        }
        /**
         * Render DataList.Head refresh button.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param {object} refresh - DataList.Refresh props.
         * @return {ReactNode} DataList.Refresh node.
         */

    }, {
        key: 'renderComponentHeadRefresh',
        value: function renderComponentHeadRefresh(refresh) {
            var _this5 = this;

            if (!refresh) return null;
            var label = refresh.label,
                float = refresh.float;

            var style = _extends({
                float: float || 'left'
            }, headMarginMap[float || 'left']);
            var refreshNode = _react2.default.createElement(
                'div',
                { style: style },
                _react2.default.createElement(
                    _button2.default,
                    { icon: label ? null : 'redo',
                        onClick: function onClick() {
                            return _this5.startLoadingData()();
                        } },
                    label
                )
            );
            return refreshNode;
        }
        /**
         * Render DataList.Head filter.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param {Array} filters - DataList.Filter props.
         * @return {ReactNode} DataList.Filter node.
         */

    }, {
        key: 'renderComponentHeadFilters',
        value: function renderComponentHeadFilters(filters) {
            var children = filters.children,
                _filters$float = filters.float,
                float = _filters$float === undefined ? 'left' : _filters$float,
                multiple = filters.multiple;

            var style = multiple ? {} : _extends({
                display: 'flex',
                float: float
            }, headMarginMap[float]);
            return children.length ? _react2.default.createElement(
                'div',
                { style: style },
                _react2.default.createElement(_DataListFilter.DataListFilterComponent, { filter: children,
                    onSearch: this.handleFilterChange(),
                    onMultipleSearch: this.handleMultipleFilterChange(),
                    multiple: multiple })
            ) : null;
        }
        /**
         * Render DataList.Head actions.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param {Array} action - DataList.Action props.
         * @return {ReactNode} DataList.Action node.
         */

    }, {
        key: 'renderComponentHeadActions',
        value: function renderComponentHeadActions(action) {
            if (!action) return null;
            // const acts = action.map((i) => i).reverse();
            var _action$float = action.float,
                float = _action$float === undefined ? 'left' : _action$float;

            var style = _extends({
                float: float
            }, headMarginMap[float]);
            var _state4 = this.state,
                selectedKeys = _state4.selectedKeys,
                selectedRows = _state4.selectedRows;
            var disabled = action.disabled;

            disabled = (0, _rcJsUtils.exec)(disabled, selectedKeys, selectedRows);
            var message = disabled.isDisabled ? disabled.message : null;
            var isDisabled = disabled.isDisabled ? 'disabled' : null;
            return _react2.default.createElement(
                'div',
                { style: style },
                _react2.default.createElement(
                    _tooltip2.default,
                    { title: message },
                    _react2.default.createElement(
                        _button2.default,
                        { type: action.type,
                            disabled: isDisabled,
                            onClick: function onClick() {
                                return (0, _rcJsUtils.exec)(action.onClick, selectedKeys, selectedRows);
                            },
                            style: { visibility: action.visible ? 'block' : 'hidden' }
                        },
                        action.label
                    )
                )
            );
        }
        /**
         * Render DataList.Head actions menus.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param {Array} menu - DataList.ActionMenu props.
         * @return {ReactNode} DataList.ActionMenu node.
         */

    }, {
        key: 'renderComponentHeadMenus',
        value: function renderComponentHeadMenus(menu) {
            var _this6 = this;

            if (!menu) return null;
            var label = menu.label,
                type = menu.type,
                _menu$float = menu.float,
                float = _menu$float === undefined ? 'left' : _menu$float;

            var style = _extends({
                float: float
            }, headMarginMap[float]);
            var itemStyle = {
                display: 'inline-block',
                width: '100%'
            };
            var actions = menu.actions;

            var menuItem = actions.map(function (act, index) {
                var disabled = act.disabled;
                var _state5 = _this6.state,
                    selectedKeys = _state5.selectedKeys,
                    selectedRows = _state5.selectedRows;

                disabled = (0, _rcJsUtils.exec)(disabled, selectedKeys, selectedRows);
                var message = disabled.isDisabled ? disabled.message : null;
                var item = _react2.default.createElement(
                    'span',
                    { onClick: function onClick() {
                            return (0, _rcJsUtils.exec)(act.onClick, selectedKeys, selectedRows);
                        } },
                    act.label
                );
                var disabledItem = _react2.default.createElement(
                    'a',
                    { disabled: 'disabled' },
                    act.label
                );
                return _react2.default.createElement(
                    _menu2.default.Item,
                    { key: index },
                    _react2.default.createElement(
                        _tooltip2.default,
                        { title: message },
                        _react2.default.createElement(
                            'span',
                            { style: itemStyle },
                            disabled.isDisabled ? disabledItem : item
                        )
                    )
                );
            });
            var actionMenu = _react2.default.createElement(
                _menu2.default,
                null,
                menuItem
            );
            return _react2.default.createElement(
                _dropdown2.default,
                { overlay: actionMenu },
                _react2.default.createElement(
                    _button2.default,
                    { style: style, type: type },
                    label,
                    ' ',
                    _react2.default.createElement(_icon2.default, { type: 'down' })
                )
            );
        }
        /**
         * Render filter tags.
         * @since 0.1.4
         * @author liujiali
         * @private
         * @return {ReactNode} Filter tags node.
         */

    }, {
        key: 'renderFilterTags',
        value: function renderFilterTags() {
            var _this7 = this;

            var filters = this.state.filters;

            var style = { marginRight: 8 };
            return filters.length ? _react2.default.createElement(
                _react.Fragment,
                null,
                _react2.default.createElement(_icon2.default, { type: 'filter', style: style }),
                filters.map(function (f, index) {
                    return _react2.default.createElement(
                        _tag2.default,
                        { color: 'blue',
                            closable: true,
                            onClose: function onClose() {
                                return _this7.handleDeleteFilter(index);
                            },
                            key: f.dataKey },
                        f.label,
                        ': ',
                        f.valueLabel
                    );
                })
            ) : null;
        }
        /**
         * Handle close filter tags.
         * @since 0.1.4
         * @author liujiali
         * @private
         * @param {number} index - Filter tags index.
         */

    }, {
        key: 'handleDeleteFilter',
        value: function handleDeleteFilter(index) {
            var filters = this.state.filters;

            filters.splice(index, 1);
            this.setState({
                filters: filters
            }, this.startLoadingData());
        }
        /**
         * Set DataList current filter.
         * @since 0.1.2
         * @author liujiali
         * @private
         * @param  {object} filter - Current filter.
         * @return {function} Filter change handler.
         */

    }, {
        key: 'handleFilterChange',
        value: function handleFilterChange() {
            var _this8 = this;

            return function (filter) {
                var filters = _this8.state.filters;

                var existFilter = (0, _lodash.find)(filters, function (i) {
                    return i.dataKey === filter.dataKey;
                });
                if (existFilter) {
                    existFilter.value = filter.value;
                    existFilter.valueLabel = filter.valueLabel;
                } else {
                    filters.push(filter);
                }
                _this8.setState({
                    filters: filters
                }, _this8.startLoadingData());
            };
        }
        /**
         * Set DataList multiple filter.
         * @since 0.2.6
         * @author liujiali
         * @private
         * @param  {object} filter - Filters.
         * @return {function} Filter change handler.
         */

    }, {
        key: 'handleMultipleFilterChange',
        value: function handleMultipleFilterChange() {
            var _this9 = this;

            return function (filters) {
                _this9.setState({
                    filters: filters
                }, _this9.startLoadingData());
            };
        }
        /**
         * DataList onChange handle function.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @return {function} DataList onChange handle function.
         */

    }, {
        key: 'handleDataListChange',
        value: function handleDataListChange() {
            var _this10 = this;

            return function (pagination, filters, sorts) {
                var _state$pagination2 = _this10.state.pagination,
                    currentPage = _state$pagination2.currentPage,
                    pageSize = _state$pagination2.pageSize,
                    total = _state$pagination2.total;

                var currentPagination = {
                    currentPage: pagination.currentPage || currentPage,
                    pageSize: pagination.pageSize || pageSize,
                    total: pagination.total || total
                };
                _this10.setState({
                    pagination: currentPagination,
                    filters: filters,
                    sorts: sorts
                }, _this10.startLoadingData());
            };
        }
        /**
         * Handle component onSelect event.
         * @since 0.1.5
         * @author liujiali
         * @private
         * @return {function} onSelect event handler.
         */

    }, {
        key: 'handleDataListSelect',
        value: function handleDataListSelect() {
            var _this11 = this;

            return function (keys, rows) {
                var rowSelection = _this11.props.rowSelection;

                if ((0, _lodash.isObject)(rowSelection)) {
                    var onChange = rowSelection.onChange;

                    (0, _rcJsUtils.exec)(onChange, keys, rows);
                }
                _this11.setState({
                    selectedKeys: keys,
                    selectedRows: rows
                });
            };
        }
        /**
         * Load DataList data.
         * @since 0.1.5
         * @author liujiali
         * @public
         * @param {boolean} slient - show table loading or not.
         * @return {function} Backward compatible returns.
         */

    }, {
        key: 'loadData',
        value: function loadData(slient) {
            this.startLoadingData()(slient);
            // Backward compatible
            return function () {};
        }
        /**
         * Get selected row data.
         * @since 0.1.5
         * @author liujiali
         * @public
         * @return {Array} Selected row data.
         */

    }, {
        key: 'getSelectedRows',
        value: function getSelectedRows() {
            var selectedRows = this.state.selectedRows;

            return selectedRows;
        }
        /**
         * Get DataList data.
         * @since 0.2.9
         * @author liujiali
         * @public
         * @return {Array} DataList data.
         */

    }, {
        key: 'getDataListData',
        value: function getDataListData() {
            var data = this.state.data;

            return data;
        }
        /**
         * Clear all DataList check state.
         * @since 0.3.0
         * @author liujiali
         * @public
         * @return {Object} Previous check state.
         */

    }, {
        key: 'clearAllCheck',
        value: function clearAllCheck() {
            var _state6 = this.state,
                selectedKeys = _state6.selectedKeys,
                selectedRows = _state6.selectedRows;

            this.setState({
                selectedKeys: [],
                selectedRows: []
            });
            return {
                selectedKeys: selectedKeys,
                selectedRows: selectedRows
            };
        }
        /**
         * Validate DataList input fields.
         * @since 0.3.2
         * @author liujiali
         * @public
         * @param {string} fields - Validate fields.
         * @param {number} index - Validate data index.
         * @return {Promise} if all fields has no error, the promise resolve, else reject.
         */

    }, {
        key: 'validateFields',
        value: function validateFields() {
            var _this12 = this;

            return new Promise(function (resolve, reject) {
                _this12.fieldsTrigger.next();
                setTimeout(function () {
                    var data = _this12.state.data;

                    var isError = false;
                    var _iteratorNormalCompletion = true;
                    var _didIteratorError = false;
                    var _iteratorError = undefined;

                    try {
                        for (var _iterator = data[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                            var dat = _step.value;
                            var _dat$fieldsError = dat.fieldsError,
                                fieldsError = _dat$fieldsError === undefined ? {} : _dat$fieldsError;

                            for (var key in fieldsError) {
                                if (fieldsError[key]) {
                                    isError = true;
                                    break;
                                }
                            }
                            if (isError) {
                                break;
                            }
                        }
                    } catch (err) {
                        _didIteratorError = true;
                        _iteratorError = err;
                    } finally {
                        try {
                            if (!_iteratorNormalCompletion && _iterator.return) {
                                _iterator.return();
                            }
                        } finally {
                            if (_didIteratorError) {
                                throw _iteratorError;
                            }
                        }
                    }

                    isError ? reject() : resolve();
                }, 0);
            });
        }
        /**
         * Manual loading table.
         * @since 0.3.7
         * @author liujiali
         * @public
         * @param {boolean} loading - Validate fields.
         */

    }, {
        key: 'startLoading',
        value: function startLoading() {
            var loading = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

            this.setState({
                loading: loading
            });
        }
        /**
         * Render method.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @return  {*} No return value.
         */

    }, {
        key: 'render',
        value: function render() {
            var _props3 = this.props,
                type = _props3.type,
                children = _props3.children;

            type = (0, _rcJsUtils.isBlank)(type) ? 'TABLE' : type.toUpperCase();
            var title = this.getDefineFromProps(children, _DataListTitle2.default);
            title = title.length ? title[0] : {};
            var head = this.getDefineFromProps(children, _DataListHead2.default);
            head = head.length ? head[0] : {};
            return _react2.default.createElement(
                _react.Fragment,
                null,
                this.renderComponentTitle(title),
                this.renderComponentHead(head),
                this.renderComponet(type === 'TABLE', _DataListTable2.default)
            );
        }
    }], [{
        key: 'loadTrigger',

        /**
         * DataList triggers loadData method.This method will be executed when componentDidMount.
         * @since 0.1.0
         * @author liujiali
         * @param {function} loadData - DataList loadData function.
         * @return {function} Stop triggers loadData.The function will be executed when componentWillUnmount.
         * @example
         *
         * DataList.loadTrigger = (loadData) => {
         *     const intervalNo = setInterval(() => loadData(true), 3000);
         *     return () => clearInterval(intervalNo);
         * }
         */
        value: function loadTrigger(loadData) {
            loadData();
            return null;
        }
        /**
         * @todo  Support observable in future.
         * @description This method is used to handle the datasource.
         *              <br/>For example, if the data comes from the Server,
         *              return the response data or just the request promise like `return fetch(data.url)`.
         *              <br/>If you are looking for the callback function of the request promise, please see `handleResponseData` method.
         * @since 0.1.0
         * @author liujiali
         * @param {*} data - props `data` in DataList.
         * @param {object} pagination - Pagination information.
         * @param {number} pagination.currentPage - Current page number.<br/>Start from 1.
         * @param {number} pagination.pageSize - Number of data items per page.
         * @param {number} pagination.total - Total item count.
         * @param {object[]} filters - Current table filter items.
         * @param {string} filters.key - Filter column key.
         * @param {string} filters.label - Filter column label.
         * @param {string} filters.value - Filter column value.
         * @param {string} filters.valueLabel - Filter column value label.
         * @param {enum} filters.type - Filter type.<br/>[`text`, `range`, `enum`, `value`].
         * @param {object[]} sorts - Current table sort items.
         * @param {string} sorts.key - Sort column key.
         * @param {enum} sorts.value - Sort column order.<br/>[`ascend`, `descend`].
         * @param {...args} args - Extra parameters.
         * @return {object} Return data for DataList component. Support object and promise.
         * @example
         * DataList.handleRequestData = (data, pagination, filters, sorts) => {
         *     return getListData(data, {
         *         currentPage: pagination.currentPage,
         *         pageSize: pagination.pageSize,
         *         sort: sorts.map(i => {
         *             i.value = i.value.replace(/end/g, '');
         *             return i;
         *         }),
         *         filter: filters
         *     })
         * }
         */

    }, {
        key: 'handleRequestData',
        value: function handleRequestData(data, pagination, filters, sorts) {
            return {
                pagination: pagination,
                filters: filters,
                sorts: sorts,
                data: data
            };
        }
    }, {
        key: 'handleResponseData',

        /**
         * @description This method is uesd to handle the response data before render.
         * @since 0.1.0
         * @author liujiali
         * @param  {*} response - Resopnse data.
         * @param  {object} pagination - Pagination information.
         * @param  {number} pagination.currentPage - Current page number.<br/>Start from 1.
         * @param  {number} pagination.pageSize - Number of data items per page.
         * @param {number} pagination.total - Total item count.
         * @param  {object[]} filters - Current table filter items.
         * @param  {string} filters.key - Filter column key.
         * @param {string} filters.label - Filter column label.
         * @param  {string} filters.value - Filter column value.
         * @param {string} filters.valueLabel - Filter column value label.
         * @param  {enum} filters.type - Filter type.<br/>[`text`, `range`, `enum`, `value`].
         * @param  {object[]} sorts - Current table sort items.
         * @param  {string} sorts.key - Sort column key.
         * @param  {enum} sorts.value - Sort column order.<br/>[`ascend`, `descend`].
         * @param {*} data - DataList `data` props value.
         * @return  {object} Return data for DataList component.The data should contain data, pagination, filters and sorts key as input parameters describe.
         * @example
         * DataList.handleResponseData = (response, pagination, filters, sorts) => {
         *     pagination.total = response.allCount;
         *     return {
         *         data: response,
         *         pagination,
         *         filters,
         *         sorts
         *     }
         * }
         */
        value: function handleResponseData(response, pagination, filters, sorts, data) {
            return {
                pagination: pagination,
                filters: filters,
                sorts: sorts,
                data: (0, _lodash.isArray)(response) ? response : []
            };
        }
    }]);

    return DataList;
}(_react.Component);

DataList.Head = _DataListHead2.default;
DataList.Refresh = _DataListRefresh2.default;
DataList.Filter = _DataListFilter2.default;
DataList.FilterItem = _DataListFilter.DataListFilterItem;
DataList.Title = _DataListTitle2.default;
DataList.Column = _DataListColumn2.default;
DataList.Action = _DataListAction2.default;
DataList.Pagination = _DataListPagination2.default;
DataList.ActionMenu = _DataListActionMenu2.default;
exports.default = DataList;

/**
 * beforeLoadData method description.
 * @callback beforeLoadData
 * @since 0.1.0
 * @author liujiali
 * @param {*} data - props `data` in DataList.
 * @param {object} pagination - Pagination information.
 * @param {number} pagination.currentPage - Current page number.<br/>Start from 1.
 * @param {number} pagination.pageSize - Number of data items per page.
 * @param {number} pagination.total - Total item count.
 * @param {object[]} filters - Current table filter items.
 * @param {string} filters.dataKey - Filter column data key.
 * @param {string} filters.label - Filter column label.
 * @param {string} filters.value - Filter column value.
 * @param {string} filters.valueLabel - Filter column value label.
 * @param {enum} filters.type - Filter type.<br/>[`text`, `range`, `enum`, `value`].
 * @param {object[]} sorts - Current table sort items.
 * @param {string} sorts.key - Sort column key.
 * @param {enum} sorts.value - Sort column order.<br/>[`ascend`, `descend`].
 * @return {Array} - Return [data, pagination, filters, sorts, ...args] as parameter for handleRequestData.
 */
/**
 * afterLoadData method description.
 * @callback afterLoadData
 * @since 0.1.0
 * @author liujiali
 * @param  {*} data - props `data` in DataList.
 * @param  {object} pagination - Pagination information.
 * @param  {number} pagination.currentPage - Current page number.<br/>Start from 1.
 * @param  {number} pagination.pageSize - Number of data items per page.
 * @param  {object[]} filters - Current table filter items.
 * @param  {string} filters.dataKey - Filter column data key.
 * @param {string} filters.label - Filter column label.
 * @param  {string} filters.value - Filter column value.
 * @param {string} filters.valueLabel - Filter column value label.
 * @param  {enum} filters.type - Filter type.<br/>[`text`, `range`, `enum`, `value`].
 * @param  {object[]} sorts - Current table sort items.
 * @param  {string} sorts.key - Sort column key.
 * @param  {enum} sorts.value - Sort column order.<br/>[`ascend`, `descend`].
 * @return {Array} - Return [data, pagination, filters, sorts, ...args] as parameter for handleRequestData.
 */