'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _badge = require('antd/lib/badge');

var _badge2 = _interopRequireDefault(_badge);

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd/lib/badge/style');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _rcJsUtils = require('rc-js-utils');

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Detail.Column component.
 * @memberof Detail
 * @name Detail.Column
 * @description Define the Detail column.
 * @since 0.2.4
 * @author liujiali
 * @property {string} [label=null] - Column label.
 * @property {string} dataKey - Column data key.
 * @property {render} [render=function(value) { return value ? value : '-' }] - Column render method.
 * @property {boolean} [visible=true] - Whether column is visible.
 * @property {string} [type] - Column type.Effective when type=`list`.
 * @property {string|object} [convert=null] - Several predefined render method.[`date`, `status`, `number`, `string`].
 *                                            <br/>If the `render` property is defined, this props will not be used.
 * @property {enum} convert.type - Convert type.[`date`, `status`, `number`, `string`].
 * @property {string} [convert.format=`YYYY-MM-DD HH:mm:ss`] - Effective when type=`date`.<br/>Date format.
 * @property {number} [convert.timezone=local timezone] - Effective when type=`date`.<br/>Date convert target timezone.
 * @property {object} [convert.statusMap] - Effective when type=`status`.<br/>Status map.
 * @property {string} convert.statusMap.key - Status map key.
 * @property {string} convert.statusMap.value - Status map value.<br/>[`success`, `warning`, `error`, `processing`, `default`].
 * @property {function} [convert.render] - Status label render.
 * @property {string} [help] - Column help message.
 * @property {boolean} [colon=true] - Wheather show colon or not.
 * @example
 * <Detail>
 *     <Detail.ColumnGroup>
 *         <Detail.Column label='Name' dataKey='name' render: val => val />
 *         ......
 *     </Detail.ColumnGroup>
 *     ......
 * </Detail>
 */
var DetailColumn = function () {
    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    function DetailColumn(props) {
        _classCallCheck(this, DetailColumn);

        var defaultAttrs = {
            label: null,
            dataKey: null,
            render: this.getDefaultRender(props),
            visible: true,
            convert: null,
            help: null
        };
        this.attrs = Object.assign(defaultAttrs, props);
    }
    /**
     * Return default render method for column.
     * @since 0.1.1
     * @author liujiali
     * @private
     * @param {*} props - Component props.
     * @return {render} Column render method.
     */


    _createClass(DetailColumn, [{
        key: 'getDefaultRender',
        value: function getDefaultRender(props) {
            var defaultRender = function defaultRender(value) {
                return (0, _rcJsUtils.isBlank)(value) ? '-' : value;
            };
            if (!props.convert) return defaultRender;
            var convert = {};
            (0, _lodash.isString)(props.convert) ? convert.type = props.convert : convert = props.convert;
            return this.getConvertRender(convert);
        }
        /**
         * Return render method by convert type.
         * @since 0.1.1
         * @author liujiali
         * @private
         * @param {object} convert - Column convert property.
         * @return {render} Column render method.
         */

    }, {
        key: 'getConvertRender',
        value: function getConvertRender(convert) {
            var type = convert.type;
            var render = void 0;
            switch (type) {
                // `string` type.
                case 'string':
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : formatString(value);
                    };
                    break;
                // `number` type.
                case 'number':
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : formatNumber(value);
                    };
                    break;
                // `date` type.
                case 'date':
                    var format = convert.format,
                        timezone = convert.timezone;

                    var opts = {};
                    if (format) opts.format = format;
                    if (!(0, _rcJsUtils.isBlank)(timezone)) opts.timezone = timezone;
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : convertToLocalDate(value, opts);
                    };
                    break;
                // `string` type.
                case 'status':
                    var statusMap = convert.statusMap;

                    if (!statusMap) {
                        statusMap = {
                            success: 'success',
                            error: 'error',
                            default: 'default',
                            processing: 'processing',
                            warning: 'warning'
                        };
                    }
                    var statusRender = convert.render || function (val) {
                        return formatString(val);
                    };
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : _react2.default.createElement(_badge2.default, { status: statusMap[value],
                            text: (0, _rcJsUtils.exec)(statusRender, value) });
                    };
                    break;
                default:
                    render = function render(value) {
                        return (0, _rcJsUtils.isBlank)(value) ? '-' : value;
                    };
            };
            return render;
        }
    }]);

    return DetailColumn;
}();

exports.default = DetailColumn;