'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _DetailColumn = require('./DetailColumn');

var _DetailColumn2 = _interopRequireDefault(_DetailColumn);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Detail.ColumnGroup component.
 * @memberof Detail
 * @name Detail.ColumnGroup
 * @description Define the Detail column group.
 * @since 0.2.4
 * @author liujiali
 * @property {number} [labelWidth=120] - Column label width.
 * @example
 * <Detail>
 *     <Detail.ColumnGroup>
 *         <Detail.Column label='Name' dataKey='name' render: val => val />
 *         ......
 *     </Detail.ColumnGroup>
 *     ......
 * </Detail>
 */
var DetailColumnGroup =
/**
 * Create and initialize component.
 * @param {*} props - Component props.
 */
function DetailColumnGroup(props) {
    _classCallCheck(this, DetailColumnGroup);

    var defaultAttrs = {
        labelWidth: 120,
        columns: []
    };
    var children = props.children;

    var columns = [];
    _react2.default.Children.map(children, function (child) {
        var ChildComponent = child.type;
        var childIns = new ChildComponent(child.props);
        if (childIns instanceof _DetailColumn2.default) {
            columns.push(childIns.attrs);
        }
    });
    var attrs = Object.assign(defaultAttrs, { columns: columns });
    this.attrs = attrs;
};

exports.default = DetailColumnGroup;