'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _row = require('antd/lib/row');

var _row2 = _interopRequireDefault(_row);

var _col = require('antd/lib/col');

var _col2 = _interopRequireDefault(_col);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd/lib/row/style');

require('antd/lib/col/style');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _rcJsUtils = require('rc-js-utils');

var _DetailTitle = require('./DetailTitle');

var _DetailTitle2 = _interopRequireDefault(_DetailTitle);

var _DetailColumnGroup = require('./DetailColumnGroup');

var _DetailColumnGroup2 = _interopRequireDefault(_DetailColumnGroup);

var _DetailColumn = require('./DetailColumn');

var _DetailColumn2 = _interopRequireDefault(_DetailColumn);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var DetailTitleStyle = {
    fontSize: 20,
    lineHeight: '28px'
};

var DetailLabelStyle = {
    minHeight: 36,
    lineHeight: '36px',
    paddingLeft: 12,
    paddingRight: 12
};

var DetailBorder = {
    borderBottom: '1px solid #e8e8e8'
};

/**
 * Detail component.
 * @namespace Detail
 * @description Define the Detail.
 * @since 0.2.4
 * @author liujiali
 * @property {object} data - Detail data.
 * @example
 * <Detail data={{name: 'Name'}}>
 *     <Detail.Title title='Detail' />
 *     <Detail.ColumnGroup>
 *         <Detail.Column label='Name' dataKey='name' />
 *     </Detail.ColumnGroup>
 *     ......
 * </Detail>
 */

var DetailList = function (_Component) {
    _inherits(DetailList, _Component);

    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    function DetailList(props) {
        _classCallCheck(this, DetailList);

        return _possibleConstructorReturn(this, (DetailList.__proto__ || Object.getPrototypeOf(DetailList)).call(this, props));
    }

    _createClass(DetailList, [{
        key: 'getDefineFromProps',


        /**
         * Get the definition of column, action and etc. by parameters.
         * @since 0.1.0
         * @author liujiali
         * @private
         * @param  {ReactNode|ReactNode[]} children - Component children nodes.
         * @param  {class} targetClass - Component class.
         * @return {Array} Component definition list.
         */
        value: function getDefineFromProps(children, targetClass) {
            var attrs = [];
            _react2.default.Children.map(children, function (child) {
                var ChildComponent = child.type;
                var childIns = new ChildComponent(child.props);
                if (childIns instanceof targetClass) {
                    attrs.push(childIns.attrs);
                }
            });
            return attrs;
        }
    }, {
        key: 'render',

        /**
         * Render method.
         * @since 0.2.4
         * @author liujiali
         * @private
         * @return  {*} No return value.
         */
        value: function render() {
            var _props = this.props,
                children = _props.children,
                data = _props.data;

            var title = this.getDefineFromProps(children, _DetailTitle2.default);
            var columnGroup = this.getDefineFromProps(children, _DetailColumnGroup2.default);
            title = title.length ? title[0] : {};
            var colSpan = 24 / columnGroup.length;
            var bordered = this.props.bordered;

            return _react2.default.createElement(
                _react.Fragment,
                null,
                title.title || title.children ? _react2.default.createElement(
                    _row2.default,
                    { style: { marginBottom: 16 } },
                    _react2.default.createElement(
                        _col2.default,
                        { style: DetailTitleStyle },
                        title.title
                    ),
                    _react2.default.createElement(
                        _col2.default,
                        null,
                        title.children
                    )
                ) : null,
                _react2.default.createElement(
                    _row2.default,
                    null,
                    columnGroup.map(function (colGrp, index) {
                        var labelWidth = colGrp.labelWidth;

                        return _react2.default.createElement(
                            _col2.default,
                            { span: colSpan, key: index },
                            colGrp.columns.map(function (col, index) {
                                var labelStyle = _extends({}, DetailLabelStyle, {
                                    width: labelWidth
                                });
                                var dataStyle = _extends({}, DetailLabelStyle, {
                                    width: 'calc(100% - ' + labelWidth + 'px)'
                                });
                                var value = data[col.dataKey];
                                var colon = true;
                                if ((0, _lodash.isBoolean)(col.colon) && !col.colon) {
                                    colon = false;
                                }
                                return _react2.default.createElement(
                                    _row2.default,
                                    { key: index, style: bordered ? DetailBorder : {} },
                                    _react2.default.createElement(
                                        _col2.default,
                                        { style: labelStyle, span: 1 },
                                        col.label,
                                        colon ? ':' : ''
                                    ),
                                    _react2.default.createElement(
                                        _col2.default,
                                        { style: dataStyle, span: 1 },
                                        (0, _rcJsUtils.exec)(col.render, value)
                                    )
                                );
                            })
                        );
                    })
                )
            );
        }
    }]);

    return DetailList;
}(_react.Component);

DetailList.Title = _DetailTitle2.default;
DetailList.ColumnGroup = _DetailColumnGroup2.default;
DetailList.Column = _DetailColumn2.default;
exports.default = DetailList;