'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.FormItem = undefined;

var _row = require('antd/lib/row');

var _row2 = _interopRequireDefault(_row);

var _col = require('antd/lib/col');

var _col2 = _interopRequireDefault(_col);

var _tooltip = require('antd/lib/tooltip');

var _tooltip2 = _interopRequireDefault(_tooltip);

var _icon = require('antd/lib/icon');

var _icon2 = _interopRequireDefault(_icon);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('antd/lib/row/style');

require('antd/lib/col/style');

require('antd/lib/tooltip/style');

require('antd/lib/icon/style');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _rcJsUtils = require('rc-js-utils');

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var tipStyle = {
    color: '#bbb',
    lineHeight: '18px'
};

var labelStyle = {
    height: 32,
    lineHeight: '32px',
    marginLeft: 20
};

var labelSty = {
    display: 'flex',
    alignItems: 'center'
};

var requiredClass = 'ant-form-item-required';
var formHelpClass = 'ant-form-item ant-form-item-with-help has-error';
var formClass = 'ant-form-item';

var FormBasicInput = function FormBasicInput() {
    return function (WrappedComponent) {
        /**
         * FormItem basic component.
         * @name FormBasicInput
         * @property {string} label - Form item label.
         * @property {string} dataKey - Form item key.
         * @property {string} [help] - Form item label tooltip.
         * @property {string} [tips] - Form item bottom tips message.
         * @property {boolean} [required=false] - Required or not.
         * @description FormItem basic component.
         * @since 0.2.1
         * @author liujiali
         * @interface
        */
        var FormBasicInput = function (_Component) {
            _inherits(FormBasicInput, _Component);

            /**
             * Create and initialize component.
             * @param {*} props - Component props.
             */
            function FormBasicInput(props) {
                _classCallCheck(this, FormBasicInput);

                var _this = _possibleConstructorReturn(this, (FormBasicInput.__proto__ || Object.getPrototypeOf(FormBasicInput)).call(this, props));

                var validateOb = props.validateOb,
                    dataKey = props.dataKey;

                _this.state = {
                    error: false
                };
                validateOb.subscribe(function (errors) {
                    var error = (0, _lodash.find)(errors, function (i) {
                        return i.field === dataKey;
                    });
                    if (error) {
                        _this.setState({
                            error: true,
                            message: error.message
                        });
                    }
                });
                return _this;
            }
            /**
             * Get FormItem help.
             * @since 0.2.1
             * @author liujiali
             * @private
             * @param {string} help - FormItem label help icon text.
             * @return {ReactNode} FormItem help node.
             */


            _createClass(FormBasicInput, [{
                key: 'getFormHelp',
                value: function getFormHelp(help) {
                    if (!help) return null;
                    return _react2.default.createElement(
                        _tooltip2.default,
                        { title: help },
                        _react2.default.createElement(_icon2.default, { type: 'question-circle', style: { marginLeft: 3 } })
                    );
                }
                /**
                 * Get FormItem tips.
                 * @since 0.2.1
                 * @author liujiali
                 * @private
                 * @param {string} tips - FormItem bottom tips text.
                 * @return {ReactNode} FormItem tips node.
                 */

            }, {
                key: 'getFormTips',
                value: function getFormTips(tips) {
                    if (!tips) return null;
                    return _react2.default.createElement(
                        'label',
                        { style: tipStyle },
                        tips
                    );
                }
                /**
                 * Handle component onChange event
                 * @since 0.2.5
                 * @author liujiali
                 * @private
                 * @return {function} Child component handler.
                 */

            }, {
                key: 'handleChange',
                value: function handleChange() {
                    var _this2 = this;

                    return function (value) {
                        var _props = _this2.props,
                            onChange = _props.onChange,
                            validate = _props.validate,
                            dataKey = _props.dataKey;

                        (0, _rcJsUtils.exec)(onChange, value);
                        validate(dataKey).then(function () {
                            _this2.setState({
                                error: false
                            });
                        }).catch(function (e) {
                            _this2.setState({
                                error: true
                            });
                        });
                    };
                }
                /**
                 * Render method.
                 * @since 0.2.0
                 * @author liujiali
                 * @private
                 * @return  {*} No return value.
                 */

            }, {
                key: 'render',
                value: function render() {
                    // TODO: layout
                    var _props2 = this.props,
                        label = _props2.label,
                        help = _props2.help,
                        tips = _props2.tips,
                        required = _props2.required;

                    var labelClassName = required ? requiredClass : '';
                    var _state = this.state,
                        error = _state.error,
                        message = _state.message;

                    return _react2.default.createElement(
                        _row2.default,
                        { type: 'flex',
                            className: error ? formHelpClass : formClass },
                        _react2.default.createElement(
                            _col2.default,
                            { style: _extends({}, labelStyle, { width: 120 }) },
                            _react2.default.createElement(
                                'label',
                                { className: labelClassName, style: labelSty },
                                label,
                                this.getFormHelp(help)
                            )
                        ),
                        _react2.default.createElement(
                            _col2.default,
                            { span: 16 },
                            _react2.default.createElement(WrappedComponent, _extends({}, this.props, {
                                onChange: this.handleChange() })),
                            this.getFormTips(tips),
                            error ? _react2.default.createElement(
                                'div',
                                { className: 'ant-form-explain' },
                                message
                            ) : null
                        )
                    );
                }
            }]);

            return FormBasicInput;
        }(_react.Component);

        return FormBasicInput;
    };
};

/**
 * FormItem para component.
 * @namespace Form
 * @description TextArea component.
 * @since 0.2.1
 * @author liujiali
 * @private
 * @example
 * <Form ref={(ins) => this.form = ins}>
 *     <Form.TextArea label='Description' dataKey='desc' />
 *     ......
 * </Form>
*/

var FormItem = function (_Component2) {
    _inherits(FormItem, _Component2);

    /**
     * Create and initialize component.
     * @param {*} props - Component props.
     */
    function FormItem(props) {
        _classCallCheck(this, FormItem);

        var _this3 = _possibleConstructorReturn(this, (FormItem.__proto__ || Object.getPrototypeOf(FormItem)).call(this, props));

        var model = props.model,
            dataKey = props.dataKey,
            ob = props.ob;

        _this3.state = _extends({}, model);
        ob.subscribe(function (values) {
            _this3.setState(_extends({}, values[dataKey]));
        });
        return _this3;
    }
    /**
     * FormItem value handler.
     * @since 0.2.1
     * @author liujiali
     * @private
     * @param {function} handler - FormItem value handler.
     * @return {function} FormItem onChange handler.
     */


    _createClass(FormItem, [{
        key: 'handleChange',
        value: function handleChange(handler) {
            var _this4 = this;

            var valueHandler = handler || function (val) {
                return val;
            };
            return function (e) {
                var _props3 = _this4.props,
                    model = _props3.model,
                    onChange = _props3.onChange;

                var value = (0, _rcJsUtils.exec)(valueHandler, e);
                model.value = value;
                _this4.setState({
                    value: value
                });
                (0, _rcJsUtils.exec)(onChange, value);
            };
        }
    }]);

    return FormItem;
}(_react.Component);

exports.FormItem = FormItem;
exports.default = FormBasicInput;